@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "4.1.65172"
+IAddressBook_VERSION = "5.0.7187"
 
 
 class IAddressBook(BaseEndpoint):
@@ -33,48 +33,28 @@ class IAddressBook(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}', containerUid)
 
-    def getVersion(self):
-        postUri = "/_version"
+    def allIds(self, filter, knownContainerVersion, limit, offset):
+        postUri = "/_itemIds"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'filter': filter, 'knownContainerVersion':
+                       knownContainerVersion, 'limit': limit, 'offset': offset}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+
+    def allUids(self):
+        postUri = "/_all"
         __data__ = None
         __encoded__ = None
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.LONG, response)
-
-    def filteredChangesetById(self, since, arg1):
-        postUri = "/_filteredChangesetById"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'since': since}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemVersion import ItemVersion
-        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
-
-    def itemChangelog(self, uid, arg1):
-        postUri = "/{uid}/_itemchangelog"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
     def changeset(self, since):
         postUri = "/_changeset"
@@ -100,102 +80,48 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
 
-    def containerChangelog(self, arg0):
-        postUri = "/_changelog"
+    def copy(self, uids, destContainerUid):
+        postUri = "/_copy/{destContainerUid}"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
-    def allIds(self, filter, knownContainerVersion, limit, offset):
-        postUri = "/_itemIds"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'filter': filter, 'knownContainerVersion':
-                       knownContainerVersion, 'limit': limit, 'offset': offset}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
-
-    def multipleGetById(self, arg0):
-        postUri = "/_mgetById"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
         __encoded__ = json.dumps(__data__)
+        postUri = postUri.replace("{destContainerUid}", destContainerUid)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
-
-    def getCompleteById(self, id):
-        postUri = "/{id}/completeById"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
-
-    def multipleDeleteById(self, arg0):
-        postUri = "/_multipleDelete"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def updateById(self, id, arg1):
-        postUri = "/id/{id}"
+    def count(self, arg0):
+        postUri = "/_count"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        __data__ = __VCardSerDer__().encode(arg1)
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
+        from netbluemind.core.container.api.Count import Count
+        from netbluemind.core.container.api.Count import __CountSerDer__
+        return self.handleResult__(__CountSerDer__(), response)
 
-    def deleteById(self, id):
-        postUri = "/id/{id}"
+    def create(self, uid, card):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{id}", id)
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        __data__ = __VCardSerDer__().encode(card)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
     def createById(self, id, arg1):
@@ -215,88 +141,6 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.api.Ack import __AckSerDer__
         return self.handleResult__(__AckSerDer__(), response)
 
-    def count(self, arg0):
-        postUri = "/_count"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.Count import Count
-        from netbluemind.core.container.api.Count import __CountSerDer__
-        return self.handleResult__(__CountSerDer__(), response)
-
-    def sortedIds(self, arg0):
-        postUri = "/_sorted"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
-        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
-        __data__ = __SortDescriptorSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
-
-    def getPhoto(self, uid):
-        postUri = "/{uid}/photo"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
-
-    def allUids(self):
-        postUri = "/_all"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
-    def update(self, uid, card):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        __data__ = __VCardSerDer__().encode(card)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def updates(self, changes):
-        postUri = "/_mupdates"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.addressbook.api.VCardChanges import VCardChanges
-        from netbluemind.addressbook.api.VCardChanges import __VCardChangesSerDer__
-        __data__ = __VCardChangesSerDer__().encode(changes)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
-        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
-        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
-
     def delete(self, uid):
         postUri = "/{uid}"
         __data__ = None
@@ -308,6 +152,17 @@ class IAddressBook(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def deleteById(self, id):
+        postUri = "/id/{id}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
     def deletePhoto(self, uid):
         postUri = "/{uid}/photo"
         __data__ = None
@@ -319,6 +174,183 @@ class IAddressBook(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def filteredChangesetById(self, since, arg1):
+        postUri = "/_filteredChangesetById"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {'since': since}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemVersion import ItemVersion
+        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}/complete"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+
+    def getCompleteById(self, id):
+        postUri = "/{id}/completeById"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+
+    def getIcon(self, uid):
+        postUri = "/{uid}/icon"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
+
+    def getInfo(self, uid):
+        postUri = "/{uid}/info"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCardInfo import VCardInfo
+        from netbluemind.addressbook.api.VCardInfo import __VCardInfoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VCardInfoSerDer__()), response)
+
+    def getPhoto(self, uid):
+        postUri = "/{uid}/photo"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
+
+    def getVersion(self):
+        postUri = "/_version"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.LONG, response)
+
+    def itemChangelog(self, uid, arg1):
+        postUri = "/{uid}/_itemchangelog"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+
+    def move(self, uids, destContainerUid):
+        postUri = "/_move/{destContainerUid}"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        postUri = postUri.replace("{destContainerUid}", destContainerUid)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def multipleDeleteById(self, arg0):
+        postUri = "/_multipleDelete"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def multipleGet(self, uids):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
+
+    def multipleGetById(self, arg0):
+        postUri = "/_mgetById"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
+
+    def reset(self):
+        postUri = "/_reset"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
     def search(self, query):
         postUri = "/_search"
         __data__ = None
@@ -339,83 +371,12 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.api.ListResult import __ListResultSerDer__
         return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VCardInfoSerDer__())), response)
 
-    def create(self, uid, card):
-        postUri = "/{uid}"
+    def setPhoto(self, uid, photo):
+        postUri = "/{uid}/photo"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        __data__ = __VCardSerDer__().encode(card)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def copy(self, uids, destContainerUid):
-        postUri = "/_copy/{destContainerUid}"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        postUri = postUri.replace("{destContainerUid}", destContainerUid)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def move(self, uids, destContainerUid):
-        postUri = "/_move/{destContainerUid}"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        postUri = postUri.replace("{destContainerUid}", destContainerUid)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def multipleGet(self, uids):
-        postUri = "/_mget"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
-
-    def getInfo(self, uid):
-        postUri = "/{uid}/info"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCardInfo import VCardInfo
-        from netbluemind.addressbook.api.VCardInfo import __VCardInfoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VCardInfoSerDer__()), response)
-
-    def touch(self, uid):
-        postUri = "/{uid}/_touch"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.STRING.encode(uid)
+        __data__ = serder.ByteArraySerDer.encode(photo)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
@@ -423,6 +384,20 @@ class IAddressBook(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def sortedIds(self, arg0):
+        postUri = "/_sorted"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
+
     def sync(self, since, changes):
         postUri = "/_sync"
         __data__ = None
@@ -439,38 +414,11 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
 
-    def getIcon(self, uid):
-        postUri = "/{uid}/icon"
+    def touch(self, uid):
+        postUri = "/{uid}/_touch"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
-
-    def getComplete(self, uid):
-        postUri = "/{uid}/complete"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
-
-    def setPhoto(self, uid, photo):
-        postUri = "/{uid}/photo"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.ByteArraySerDer.encode(photo)
+        __data__ = serder.STRING.encode(uid)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
@@ -478,12 +426,50 @@ class IAddressBook(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def reset(self):
-        postUri = "/_reset"
+    def update(self, uid, card):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        __data__ = __VCardSerDer__().encode(card)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
+
+    def updateById(self, id, arg1):
+        postUri = "/id/{id}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        __data__ = __VCardSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+
+    def updates(self, changes):
+        postUri = "/_mupdates"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.addressbook.api.VCardChanges import VCardChanges
+        from netbluemind.addressbook.api.VCardChanges import __VCardChangesSerDer__
+        __data__ = __VCardChangesSerDer__().encode(changes)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBook_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
+        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
+        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
