@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAPIKeys_VERSION = "4.1.65172"
+IAPIKeys_VERSION = "5.0.7187"
 
 
 class IAPIKeys(BaseEndpoint):
@@ -31,17 +31,17 @@ class IAPIKeys(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url + '/auth/keys'
 
-    def list(self):
+    def create(self, displayName):
         postUri = ""
         __data__ = None
         __encoded__ = None
-        queryParams = {}
+        queryParams = {'displayName': displayName}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAPIKeys_VERSION}, data=__encoded__)
         from netbluemind.authentication.api.APIKey import APIKey
         from netbluemind.authentication.api.APIKey import __APIKeySerDer__
-        return self.handleResult__(serder.ListSerDer(__APIKeySerDer__()), response)
+        return self.handleResult__(__APIKeySerDer__(), response)
 
     def delete(self, sid):
         postUri = "/{sid}"
@@ -67,10 +67,23 @@ class IAPIKeys(BaseEndpoint):
         from netbluemind.authentication.api.APIKey import __APIKeySerDer__
         return self.handleResult__(__APIKeySerDer__(), response)
 
-    def create(self, displayName):
+    def list(self):
         postUri = ""
         __data__ = None
         __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAPIKeys_VERSION}, data=__encoded__)
+        from netbluemind.authentication.api.APIKey import APIKey
+        from netbluemind.authentication.api.APIKey import __APIKeySerDer__
+        return self.handleResult__(serder.ListSerDer(__APIKeySerDer__()), response)
+
+    def store(self, key, displayName):
+        postUri = "/{key}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{key}", key)
         queryParams = {'displayName': displayName}
 
         response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
