@@ -22,25 +22,24 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailConversation_VERSION = "4.1.65172"
+IMailConversation_VERSION = "5.0.7187"
 
 
 class IMailConversation(BaseEndpoint):
-    def __init__(self, apiKey, url, conversationContainer):
+    def __init__(self, apiKey, url, subtreeContainer):
         self.url = url
         self.apiKey = apiKey
-        self.base = url + '/mail_conversation/{conversationContainer}'
-        self.conversationContainer_ = conversationContainer
-        self.base = self.base.replace(
-            '{conversationContainer}', conversationContainer)
+        self.base = url + '/mail_conversation/{subtreeContainer}'
+        self.subtreeContainer_ = subtreeContainer
+        self.base = self.base.replace('{subtreeContainer}', subtreeContainer)
 
-    def byFolder(self, folder, filter):
+    def byFolder(self, folder, sorted):
         postUri = ""
         __data__ = None
         __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(filter)
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(sorted)
         __encoded__ = json.dumps(__data__)
         queryParams = {'folder': folder}
 
@@ -48,6 +47,19 @@ class IMailConversation(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversation_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
+    def get(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversation_VERSION}, data=__encoded__)
+        from netbluemind.backend.mail.api.Conversation import Conversation
+        from netbluemind.backend.mail.api.Conversation import __ConversationSerDer__
+        return self.handleResult__(__ConversationSerDer__(), response)
+
     def multipleGet(self, uids):
         postUri = "/_mget"
         __data__ = None
@@ -60,33 +72,4 @@ class IMailConversation(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversation_VERSION}, data=__encoded__)
         from netbluemind.backend.mail.api.Conversation import Conversation
         from netbluemind.backend.mail.api.Conversation import __ConversationSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ConversationSerDer__())), response)
-
-    def removeMessage(self, containerUid, itemId):
-        postUri = "/{containerUid}/{itemId}/_message"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{containerUid}", containerUid)
-        postUri = postUri.replace("{itemId}", itemId)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversation_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getComplete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversation_VERSION}, data=__encoded__)
-        from netbluemind.backend.mail.api.Conversation import Conversation
-        from netbluemind.backend.mail.api.Conversation import __ConversationSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__ConversationSerDer__()), response)
+        return self.handleResult__(serder.ListSerDer(__ConversationSerDer__()), response)
