@@ -25,7 +25,6 @@ class ImportMailboxItemSet:
     def __init__(self):
         self.mailboxFolderId = None
         self.ids = None
-        self.expectedIds = None
         self.deleteFromSource = None
         pass
 
@@ -50,11 +49,6 @@ class __ImportMailboxItemSetSerDer__:
         idsValue = value['ids']
         instance.ids = serder.ListSerDer(
             __ImportMailboxItemSetMailboxItemIdSerDer__()).parse(idsValue)
-        from netbluemind.backend.mail.api.ImportMailboxItemSetMailboxItemId import ImportMailboxItemSetMailboxItemId
-        from netbluemind.backend.mail.api.ImportMailboxItemSetMailboxItemId import __ImportMailboxItemSetMailboxItemIdSerDer__
-        expectedIdsValue = value['expectedIds']
-        instance.expectedIds = serder.ListSerDer(
-            __ImportMailboxItemSetMailboxItemIdSerDer__()).parse(expectedIdsValue)
         deleteFromSourceValue = value['deleteFromSource']
         instance.deleteFromSource = serder.BOOLEAN.parse(deleteFromSourceValue)
         return instance
@@ -75,11 +69,6 @@ class __ImportMailboxItemSetSerDer__:
         idsValue = value.ids
         instance["ids"] = serder.ListSerDer(
             __ImportMailboxItemSetMailboxItemIdSerDer__()).encode(idsValue)
-        from netbluemind.backend.mail.api.ImportMailboxItemSetMailboxItemId import ImportMailboxItemSetMailboxItemId
-        from netbluemind.backend.mail.api.ImportMailboxItemSetMailboxItemId import __ImportMailboxItemSetMailboxItemIdSerDer__
-        expectedIdsValue = value.expectedIds
-        instance["expectedIds"] = serder.ListSerDer(
-            __ImportMailboxItemSetMailboxItemIdSerDer__()).encode(expectedIdsValue)
         deleteFromSourceValue = value.deleteFromSource
         instance["deleteFromSource"] = serder.BOOLEAN.encode(
             deleteFromSourceValue)
