@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IUserCalendarViews_VERSION = "4.1.65172"
+IUserCalendarViews_VERSION = "5.0.7187"
 
 
 class IUserCalendarViews(BaseEndpoint):
@@ -35,23 +35,44 @@ class IUserCalendarViews(BaseEndpoint):
         self.userUid_ = userUid
         self.base = self.base.replace('{userUid}', userUid)
 
-    def multipleGet(self, uids):
-        postUri = "/_mget"
+    def allIds(self, filter, knownContainerVersion, limit, offset):
+        postUri = "/_itemIds"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
+        queryParams = {'filter': filter, 'knownContainerVersion':
+                       knownContainerVersion, 'limit': limit, 'offset': offset}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.calendar.api.CalendarView import CalendarView
-        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
 
-    def update(self, uid, view):
+    def changeset(self, since):
+        postUri = "/_changeset"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'since': since}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+
+    def changesetById(self, since):
+        postUri = "/_changesetById"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'since': since}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
+
+    def create(self, uid, view):
         postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
@@ -62,36 +83,6 @@ class IUserCalendarViews(BaseEndpoint):
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def list(self):
-        postUri = "/_list"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.calendar.api.CalendarView import CalendarView
-        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
-
-    def updates(self, changes):
-        postUri = "/_mupdates"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.calendar.api.CalendarViewChanges import CalendarViewChanges
-        from netbluemind.calendar.api.CalendarViewChanges import __CalendarViewChangesSerDer__
-        __data__ = __CalendarViewChangesSerDer__().encode(changes)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
         response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
@@ -107,16 +98,23 @@ class IUserCalendarViews(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def setDefault(self, uid):
-        postUri = "/{uid}/_asdefault"
+    def filteredChangesetById(self, since, arg1):
+        postUri = "/_filteredChangesetById"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {'since': since}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        from netbluemind.core.container.model.ItemVersion import ItemVersion
+        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
 
     def getComplete(self, uid):
         postUri = "/{uid}"
@@ -133,37 +131,6 @@ class IUserCalendarViews(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__CalendarViewSerDer__()), response)
 
-    def create(self, uid, view):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.calendar.api.CalendarView import CalendarView
-        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
-        __data__ = __CalendarViewSerDer__().encode(view)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def multipleGetById(self, arg0):
-        postUri = "/_mgetById"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.calendar.api.CalendarView import CalendarView
-        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
-
     def getCompleteById(self, id):
         postUri = "/{id}/completeById"
         __data__ = None
@@ -189,24 +156,6 @@ class IUserCalendarViews(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
         return self.handleResult__(serder.LONG, response)
 
-    def filteredChangesetById(self, since, arg1):
-        postUri = "/_filteredChangesetById"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'since': since}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemVersion import ItemVersion
-        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
-
     def itemChangelog(self, uid, arg1):
         postUri = "/{uid}/_itemchangelog"
         __data__ = None
@@ -222,53 +171,90 @@ class IUserCalendarViews(BaseEndpoint):
         from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
         return self.handleResult__(__ItemChangelogSerDer__(), response)
 
-    def changeset(self, since):
-        postUri = "/_changeset"
+    def list(self):
+        postUri = "/_list"
         __data__ = None
         __encoded__ = None
-        queryParams = {'since': since}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-
-    def changesetById(self, since):
-        postUri = "/_changesetById"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'since': since}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
-
-    def containerChangelog(self, arg0):
-        postUri = "/_changelog"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
-    def allIds(self, filter, knownContainerVersion, limit, offset):
-        postUri = "/_itemIds"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'filter': filter, 'knownContainerVersion':
-                       knownContainerVersion, 'limit': limit, 'offset': offset}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.calendar.api.CalendarView import CalendarView
+        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         from netbluemind.core.api.ListResult import ListResult
         from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+        return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
+
+    def multipleGet(self, uids):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.calendar.api.CalendarView import CalendarView
+        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
+
+    def multipleGetById(self, arg0):
+        postUri = "/_mgetById"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        from netbluemind.calendar.api.CalendarView import CalendarView
+        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__CalendarViewSerDer__())), response)
+
+    def setDefault(self, uid):
+        postUri = "/{uid}/_asdefault"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def update(self, uid, view):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.calendar.api.CalendarView import CalendarView
+        from netbluemind.calendar.api.CalendarView import __CalendarViewSerDer__
+        __data__ = __CalendarViewSerDer__().encode(view)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def updates(self, changes):
+        postUri = "/_mupdates"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.calendar.api.CalendarViewChanges import CalendarViewChanges
+        from netbluemind.calendar.api.CalendarViewChanges import __CalendarViewChangesSerDer__
+        __data__ = __CalendarViewChangesSerDer__().encode(changes)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserCalendarViews_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
