@@ -24,6 +24,7 @@ from netbluemind.python import serder
 class Ack:
     def __init__(self):
         self.version = None
+        self.timestamp = None
         pass
 
 
@@ -42,6 +43,8 @@ class __AckSerDer__:
     def parseInternal(self, value, instance):
         versionValue = value['version']
         instance.version = serder.LONG.parse(versionValue)
+        timestampValue = value['timestamp']
+        instance.timestamp = serder.DATE.parse(timestampValue)
         return instance
 
     def encode(self, value):
@@ -55,4 +58,6 @@ class __AckSerDer__:
 
         versionValue = value.version
         instance["version"] = serder.LONG.encode(versionValue)
+        timestampValue = value.timestamp
+        instance["timestamp"] = serder.DATE.encode(timestampValue)
         return instance
