@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IContainerManagement_VERSION = "4.1.65172"
+IContainerManagement_VERSION = "5.0.7187"
 
 
 class IContainerManagement(BaseEndpoint):
@@ -33,27 +33,39 @@ class IContainerManagement(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}', containerUid)
 
-    def getDescriptor(self):
-        postUri = "/_descriptor"
+    def allowOfflineSync(self, subject):
+        postUri = "/{subject}/offlineSync"
         __data__ = None
         __encoded__ = None
+        postUri = postUri.replace("{subject}", subject)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
+        return self.handleResult__(None, response)
 
-    def getSettings(self):
-        postUri = "/_settings"
+    def canAccess(self, verbsOrRoles):
+        postUri = "/_canAccess"
         __data__ = None
         __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(verbsOrRoles)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.MapSerDer(serder.STRING), response)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.BOOLEAN, response)
+
+    def disallowOfflineSync(self, subject):
+        postUri = "/{subject}/offlineSync"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{subject}", subject)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
 
     def getAccessControlList(self):
         postUri = "/_acl"
@@ -79,15 +91,33 @@ class IContainerManagement(BaseEndpoint):
         from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
 
-    def subscribers(self):
-        postUri = "/_subscription"
+    def getDescriptor(self):
+        postUri = "/_descriptor"
         __data__ = None
         __encoded__ = None
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
+
+    def getFilteredItems(self, filter):
+        postUri = "/_filtered"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(filter)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
+        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
 
     def getItemCount(self):
         postUri = "/_itemCount"
@@ -101,6 +131,30 @@ class IContainerManagement(BaseEndpoint):
         from netbluemind.core.container.api.Count import __CountSerDer__
         return self.handleResult__(__CountSerDer__(), response)
 
+    def getItems(self, uids):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
+        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
+
+    def getSettings(self):
+        postUri = "/_settings"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.MapSerDer(serder.STRING), response)
+
     def setAccessControlList(self, entries):
         postUri = "/_acl"
         __data__ = None
@@ -116,25 +170,25 @@ class IContainerManagement(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def update(self, descriptor):
-        postUri = "/_descriptor"
+    def setPersonalSettings(self, settings):
+        postUri = "/_personalSettings"
         __data__ = None
         __encoded__ = None
-        from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
-        from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
-        __data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)
+        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def allowOfflineSync(self, subject):
-        postUri = "/{subject}/offlineSync"
+    def setSetting(self, key, value):
+        postUri = "/_settings/{key}"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{subject}", subject)
+        postUri = postUri.replace("{key}", key)
+        __data__ = serder.STRING.encode(value)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
@@ -153,67 +207,26 @@ class IContainerManagement(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getItems(self, uids):
-        postUri = "/_mget"
+    def subscribers(self):
+        postUri = "/_subscription"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
-        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
-
-    def disallowOfflineSync(self, subject):
-        postUri = "/{subject}/offlineSync"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{subject}", subject)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def canAccess(self, verbsOrRoles):
-        postUri = "/_canAccess"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(verbsOrRoles)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.BOOLEAN, response)
-
-    def setPersonalSettings(self, settings):
-        postUri = "/_personalSettings"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getFilteredItems(self, filter):
-        postUri = "/_filtered"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(filter)
-        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
-        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
+    def update(self, descriptor):
+        postUri = "/_descriptor"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
+        from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
+        __data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
