@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IContainers_VERSION = "4.1.65172"
+IContainers_VERSION = "5.0.7187"
 
 
 class IContainers(BaseEndpoint):
@@ -47,6 +47,79 @@ class IContainers(BaseEndpoint):
         from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
         return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
 
+    def allForUser(self, domainUid, userUid, query):
+        postUri = "/_listforuser"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
+        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
+        __data__ = __ContainerQuerySerDer__().encode(query)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {'domainUid': domainUid, 'userUid': userUid}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
+
+    def allLight(self, query):
+        postUri = "/_listLight"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
+        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
+        __data__ = __ContainerQuerySerDer__().encode(query)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
+        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)
+
+    def create(self, uid, descriptor):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        __data__ = __ContainerDescriptorSerDer__().encode(descriptor)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
+        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
+        return self.handleResult__(__BaseContainerDescriptorSerDer__(), response)
+
+    def delete(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def get(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
+
     def getContainers(self, containerIds):
         postUri = "/_mget"
         __data__ = None
@@ -61,6 +134,71 @@ class IContainers(BaseEndpoint):
         from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
         return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
 
+    def getContainersLight(self, containerIds):
+        postUri = "/_mgetLight"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(containerIds)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
+        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)
+
+    def getForUser(self, domainUid, userUid, uid):
+        postUri = "/_forUser"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'domainUid': domainUid, 'userUid': userUid, 'uid': uid}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
+
+    def getIfPresent(self, uid):
+        postUri = "/_ifPresent/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
+        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
+        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
+
+    def getLight(self, uid):
+        postUri = "/_light/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
+        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
+        return self.handleResult__(__BaseContainerDescriptorSerDer__(), response)
+
+    def getLightIfPresent(self, uid):
+        postUri = "/_ifPresentLight/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
+        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
+        return self.handleResult__(__BaseContainerDescriptorSerDer__(), response)
+
     def setAccessControlList(self, uid, entries):
         postUri = "/{uid}/_acl"
         __data__ = None
@@ -91,113 +229,3 @@ class IContainers(BaseEndpoint):
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
-
-    def allLight(self, query):
-        postUri = "/_listLight"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
-        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
-        __data__ = __ContainerQuerySerDer__().encode(query)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
-        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)
-
-    def allForUser(self, domainUid, userUid, query):
-        postUri = "/_listforuser"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
-        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
-        __data__ = __ContainerQuerySerDer__().encode(query)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'domainUid': domainUid, 'userUid': userUid}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
-
-    def delete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getContainersLight(self, containerIds):
-        postUri = "/_mgetLight"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(containerIds)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
-        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)
-
-    def get(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
-
-    def create(self, uid, descriptor):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        __data__ = __ContainerDescriptorSerDer__().encode(descriptor)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getIfPresent(self, uid):
-        postUri = "/_ifPresent/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
-
-    def getForUser(self, domainUid, userUid, uid):
-        postUri = "/_forUser"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'domainUid': domainUid, 'userUid': userUid, 'uid': uid}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
-        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
-        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
