@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IOwnerSubscriptions_VERSION = "4.1.65172"
+IOwnerSubscriptions_VERSION = "5.0.7187"
 
 
 class IOwnerSubscriptions(BaseEndpoint):
@@ -35,48 +35,18 @@ class IOwnerSubscriptions(BaseEndpoint):
         self.ownerUid_ = ownerUid
         self.base = self.base.replace('{ownerUid}', ownerUid)
 
-    def getVersion(self):
-        postUri = "/_version"
+    def allIds(self, filter, knownContainerVersion, limit, offset):
+        postUri = "/_itemIds"
         __data__ = None
         __encoded__ = None
-        queryParams = {}
+        queryParams = {'filter': filter, 'knownContainerVersion':
+                       knownContainerVersion, 'limit': limit, 'offset': offset}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.LONG, response)
-
-    def filteredChangesetById(self, since, filter):
-        postUri = "/_filteredChangesetById"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(filter)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'since': since}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemVersion import ItemVersion
-        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
-
-    def itemChangelog(self, uid, since):
-        postUri = "/{uid}/_itemchangelog"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.LONG.encode(since)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
 
     def changeset(self, since):
         postUri = "/_changeset"
@@ -102,46 +72,37 @@ class IOwnerSubscriptions(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
 
-    def containerChangelog(self, since):
-        postUri = "/_changelog"
+    def filteredChangesetById(self, since, filter):
+        postUri = "/_filteredChangesetById"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.LONG.encode(since)
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(filter)
         __encoded__ = json.dumps(__data__)
-        queryParams = {}
+        queryParams = {'since': since}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemVersion import ItemVersion
+        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
 
-    def allIds(self, filter, knownContainerVersion, limit, offset):
-        postUri = "/_itemIds"
+    def fullChangesetById(self, since):
+        postUri = "/_fullChangesetById"
         __data__ = None
         __encoded__ = None
-        queryParams = {'filter': filter, 'knownContainerVersion':
-                       knownContainerVersion, 'limit': limit, 'offset': offset}
+        queryParams = {'since': since}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
-
-    def list(self):
-        postUri = "/_list"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.ContainerSubscriptionModel import ContainerSubscriptionModel
-        from netbluemind.core.container.api.ContainerSubscriptionModel import __ContainerSubscriptionModelSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__())), response)
+        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
+        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemIdentifierSerDer__()), response)
 
     def getComplete(self, uid):
         postUri = "/{uid}/complete"
@@ -158,21 +119,20 @@ class IOwnerSubscriptions(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__()), response)
 
-    def getMultipleById(self, id):
-        postUri = "/_mgetById"
+    def getCompleteById(self, id):
+        postUri = "/{id}/completeById"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(id)
-        __encoded__ = json.dumps(__data__)
+        postUri = postUri.replace("{id}", id)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
         from netbluemind.core.container.api.ContainerSubscriptionModel import ContainerSubscriptionModel
         from netbluemind.core.container.api.ContainerSubscriptionModel import __ContainerSubscriptionModelSerDer__
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__())), response)
+        return self.handleResult__(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__()), response)
 
     def getMultiple(self, uids):
         postUri = "/_mget"
@@ -190,25 +150,35 @@ class IOwnerSubscriptions(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__())), response)
 
-    def fullChangesetById(self, since):
-        postUri = "/_fullChangesetById"
+    def getVersion(self):
+        postUri = "/_version"
         __data__ = None
         __encoded__ = None
-        queryParams = {'since': since}
+        queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
-        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemIdentifierSerDer__()), response)
+        return self.handleResult__(serder.LONG, response)
 
-    def getCompleteById(self, id):
-        postUri = "/{id}/completeById"
+    def itemChangelog(self, uid, since):
+        postUri = "/{uid}/_itemchangelog"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.LONG.encode(since)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+
+    def list(self):
+        postUri = "/_list"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{id}", id)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
@@ -217,4 +187,20 @@ class IOwnerSubscriptions(BaseEndpoint):
         from netbluemind.core.container.api.ContainerSubscriptionModel import __ContainerSubscriptionModelSerDer__
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__()), response)
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__())), response)
+
+    def multipleGetById(self, ids):
+        postUri = "/_mgetById"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOwnerSubscriptions_VERSION}, data=__encoded__)
+        from netbluemind.core.container.api.ContainerSubscriptionModel import ContainerSubscriptionModel
+        from netbluemind.core.container.api.ContainerSubscriptionModel import __ContainerSubscriptionModelSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ContainerSubscriptionModelSerDer__())), response)
