@@ -26,7 +26,9 @@ class Verb(Enum):
     Invitation = 'Invitation'
     Freebusy = 'Freebusy'
     SendOnBehalf = 'SendOnBehalf'
+    SendAs = 'SendAs'
     Read = 'Read'
+    ReadExtended = 'ReadExtended'
     Write = 'Write'
     Manage = 'Manage'
     All = 'All'
