@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IDirectory_VERSION = "4.1.65172"
+IDirectory_VERSION = "5.0.7187"
 
 
 class IDirectory(BaseEndpoint):
@@ -33,31 +33,17 @@ class IDirectory(BaseEndpoint):
         self.domain_ = domain
         self.base = self.base.replace('{domain}', domain)
 
-    def getEntryIcon(self, entryUid):
-        postUri = "/entry-uid/{entryUid}/icon"
+    def changeset(self, since):
+        postUri = "/_changeset"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{entryUid}", entryUid)
-        queryParams = {}
+        queryParams = {'since': since}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
-
-    def getVCard(self, uid):
-        postUri = "/{uid}/_vcard"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
 
     def delete(self, path):
         postUri = "/{path}"
@@ -72,17 +58,44 @@ class IDirectory(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
 
-    def changeset(self, since):
-        postUri = "/_changeset"
+    def deleteByEntryUid(self, entryUid):
+        postUri = "/_byentryuid/{entryUid}"
         __data__ = None
         __encoded__ = None
-        queryParams = {'since': since}
+        postUri = postUri.replace("{entryUid}", entryUid)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def findByEntryUid(self, entryUid):
+        postUri = "/entry-uid/{entryUid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{entryUid}", entryUid)
+        queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        return self.handleResult__(__DirEntrySerDer__(), response)
+
+    def getByEmail(self, email):
+        postUri = "/_byEmail/{email}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{email}", email)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        return self.handleResult__(__DirEntrySerDer__(), response)
 
     def getByRoles(self, roles):
         postUri = "/_byroles"
@@ -100,6 +113,132 @@ class IDirectory(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)
 
+    def getEntries(self, path):
+        postUri = "/_childs"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.STRING.encode(path)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        return self.handleResult__(serder.ListSerDer(__DirEntrySerDer__()), response)
+
+    def getEntry(self, path):
+        postUri = "/_entry"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.STRING.encode(path)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        return self.handleResult__(__DirEntrySerDer__(), response)
+
+    def getEntryIcon(self, entryUid):
+        postUri = "/entry-uid/{entryUid}/icon"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{entryUid}", entryUid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
+
+    def getEntryPhoto(self, entryUid):
+        postUri = "/entry-uid/{entryUid}/photo"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{entryUid}", entryUid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
+
+    def getIcon(self, path):
+        postUri = "/_icon/{path}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{path}", path)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
+
+    def getMultiple(self, id):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(id)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)
+
+    def getRolesForDirEntry(self, entryUid):
+        postUri = "/entry-uid/{entryUid}/rolesfor_"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{entryUid}", entryUid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getRolesForOrgUnit(self, ouUid):
+        postUri = "/ou-uid/{ouUid}/rolesfor_"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{ouUid}", ouUid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getRoot(self):
+        postUri = ""
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        return self.handleResult__(__DirEntrySerDer__(), response)
+
+    def getVCard(self, uid):
+        postUri = "/{uid}/_vcard"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+
     def search(self, query):
         postUri = "/_search"
         __data__ = None
@@ -120,85 +259,6 @@ class IDirectory(BaseEndpoint):
         from netbluemind.core.api.ListResult import __ListResultSerDer__
         return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__DirEntrySerDer__())), response)
 
-    def findByEntryUid(self, entryUid):
-        postUri = "/entry-uid/{entryUid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{entryUid}", entryUid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        return self.handleResult__(__DirEntrySerDer__(), response)
-
-    def getMultiple(self, id):
-        postUri = "/_mget"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(id)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)
-
-    def getEntryPhoto(self, entryUid):
-        postUri = "/entry-uid/{entryUid}/photo"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{entryUid}", entryUid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
-
-    def getEntry(self, path):
-        postUri = "/_entry"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.STRING.encode(path)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        return self.handleResult__(__DirEntrySerDer__(), response)
-
-    def getRoot(self):
-        postUri = ""
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        return self.handleResult__(__DirEntrySerDer__(), response)
-
-    def deleteByEntryUid(self, entryUid):
-        postUri = "/_byentryuid/{entryUid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{entryUid}", entryUid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-
     def xfer(self, entryUid, serverUid):
         postUri = "/_xfer/{entryUid}/{serverUid}"
         __data__ = None
@@ -212,75 +272,3 @@ class IDirectory(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
-
-    def getByEmail(self, email):
-        postUri = "/_byEmail/{email}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{email}", email)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        return self.handleResult__(__DirEntrySerDer__(), response)
-
-    def getRolesForDirEntry(self, entryUid):
-        postUri = "/entry-uid/{entryUid}/rolesfor_"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{entryUid}", entryUid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def changelog(self, since):
-        postUri = "/_changelog"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'since': since}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
-    def getRolesForOrgUnit(self, ouUid):
-        postUri = "/ou-uid/{ouUid}/rolesfor_"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{ouUid}", ouUid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def getIcon(self, path):
-        postUri = "/_icon/{path}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{path}", path)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
-
-    def getEntries(self, path):
-        postUri = "/_childs"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.STRING.encode(path)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
-        from netbluemind.directory.api.DirEntry import DirEntry
-        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
-        return self.handleResult__(serder.ListSerDer(__DirEntrySerDer__()), response)
