@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IDomains_VERSION = "4.1.65172"
+IDomains_VERSION = "5.0.7187"
 
 
 class IDomains(BaseEndpoint):
@@ -45,34 +45,31 @@ class IDomains(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DomainSerDer__())), response)
 
-    def findByNameOrAliases(self, name):
-        postUri = "/_lookup"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'name': name}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
-        from netbluemind.domain.api.Domain import Domain
-        from netbluemind.domain.api.Domain import __DomainSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)
-
-    def setAliases(self, uid, aliases):
-        postUri = "/{uid}/_aliases"
+    def create(self, uid, domain):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.SetSerDer(serder.STRING).encode(aliases)
+        from netbluemind.domain.api.Domain import Domain
+        from netbluemind.domain.api.Domain import __DomainSerDer__
+        __data__ = __DomainSerDer__().encode(domain)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def delete(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
 
     def deleteDomainItems(self, uid):
         postUri = "/{uid}/_items"
@@ -87,31 +84,19 @@ class IDomains(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
 
-    def update(self, uid, domain):
-        postUri = "/{uid}"
+    def findByNameOrAliases(self, name):
+        postUri = "/_lookup"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
+        queryParams = {'name': name}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
         from netbluemind.domain.api.Domain import Domain
         from netbluemind.domain.api.Domain import __DomainSerDer__
-        __data__ = __DomainSerDer__().encode(domain)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def delete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)
 
     def get(self, uid):
         postUri = "/{uid}"
@@ -128,19 +113,54 @@ class IDomains(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)
 
-    def create(self, uid, domain):
-        postUri = "/{uid}"
+    def getExternalUrl(self, uid):
+        postUri = "/{uid}/externalurl"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        from netbluemind.domain.api.Domain import Domain
-        from netbluemind.domain.api.Domain import __DomainSerDer__
-        __data__ = __DomainSerDer__().encode(domain)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.STRING, response)
+
+    def getRoles(self, uid):
+        postUri = "/{uid}/roles"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def setAliases(self, uid, aliases):
+        postUri = "/{uid}/_aliases"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.SetSerDer(serder.STRING).encode(aliases)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def setDefaultAlias(self, uid, defaultAlias):
+        postUri = "/{uid}/_default_alias"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.STRING.encode(defaultAlias)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
     def setRoles(self, uid, roles):
@@ -156,26 +176,17 @@ class IDomains(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def setDefaultAlias(self, uid, defaultAlias):
-        postUri = "/{uid}/_default_alias"
+    def update(self, uid, domain):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.STRING.encode(defaultAlias)
+        from netbluemind.domain.api.Domain import Domain
+        from netbluemind.domain.api.Domain import __DomainSerDer__
+        __data__ = __DomainSerDer__().encode(domain)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
-
-    def getRoles(self, uid):
-        postUri = "/{uid}/roles"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
