@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IFileHosting_VERSION = "4.1.65172"
+IFileHosting_VERSION = "5.0.7187"
 
 
 class IFileHosting(BaseEndpoint):
@@ -33,31 +33,6 @@ class IFileHosting(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}', domainUid)
 
-    def store(self, path, document):
-        postUri = "/{path}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{path}", path)
-        __data__ = serder.STREAM.encode(document)
-        __encoded__ = __data__
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def list(self, path):
-        postUri = "/_list"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'path': path}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
-        from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
-        return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)
-
     def delete(self, path):
         postUri = "/{path}"
         __data__ = None
@@ -69,30 +44,16 @@ class IFileHosting(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getComplete(self, uid):
-        postUri = "/{uid}/_complete"
+    def exists(self, path):
+        postUri = "/{path}/_exists"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
+        postUri = postUri.replace("{path}", path)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
-        from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
-        return self.handleResult__(__FileHostingItemSerDer__(), response)
-
-    def getConfiguration(self):
-        postUri = "/_config"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        from netbluemind.filehosting.api.Configuration import Configuration
-        from netbluemind.filehosting.api.Configuration import __ConfigurationSerDer__
-        return self.handleResult__(__ConfigurationSerDer__(), response)
+        return self.handleResult__(serder.BOOLEAN, response)
 
     def find(self, query):
         postUri = "/_find"
@@ -106,17 +67,6 @@ class IFileHosting(BaseEndpoint):
         from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
         return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)
 
-    def unShare(self, url):
-        postUri = "/{url}/unshare"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{url}", url)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
     def get(self, path):
         postUri = "/{path}/_content"
         __data__ = None
@@ -128,27 +78,41 @@ class IFileHosting(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
         return response.content
 
-    def getSharedFile(self, uid):
-        postUri = "/{uid}/_public"
+    def getConfiguration(self):
+        postUri = "/_config"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        return response.content
+        from netbluemind.filehosting.api.Configuration import Configuration
+        from netbluemind.filehosting.api.Configuration import __ConfigurationSerDer__
+        return self.handleResult__(__ConfigurationSerDer__(), response)
 
-    def exists(self, path):
-        postUri = "/{path}/_exists"
+    def info(self):
+        postUri = "/_info"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{path}", path)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.BOOLEAN, response)
+        from netbluemind.filehosting.api.FileHostingInfo import FileHostingInfo
+        from netbluemind.filehosting.api.FileHostingInfo import __FileHostingInfoSerDer__
+        return self.handleResult__(__FileHostingInfoSerDer__(), response)
+
+    def list(self, path):
+        postUri = "/_list"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'path': path}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
+        from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
+        from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
+        return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)
 
     def share(self, path, downloadLimit, expirationDate):
         postUri = "/_share"
@@ -163,14 +127,26 @@ class IFileHosting(BaseEndpoint):
         from netbluemind.filehosting.api.FileHostingPublicLink import __FileHostingPublicLinkSerDer__
         return self.handleResult__(__FileHostingPublicLinkSerDer__(), response)
 
-    def info(self):
-        postUri = "/_info"
+    def store(self, path, document):
+        postUri = "/{path}"
         __data__ = None
         __encoded__ = None
+        postUri = postUri.replace("{path}", path)
+        __data__ = serder.STREAM.encode(document)
+        __encoded__ = __data__
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
-        from netbluemind.filehosting.api.FileHostingInfo import FileHostingInfo
-        from netbluemind.filehosting.api.FileHostingInfo import __FileHostingInfoSerDer__
-        return self.handleResult__(__FileHostingInfoSerDer__(), response)
+        return self.handleResult__(None, response)
+
+    def unShare(self, url):
+        postUri = "/{url}/unshare"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{url}", url)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IFileHosting_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
