@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IGroup_VERSION = "4.1.65172"
+IGroup_VERSION = "5.0.7187"
 
 
 class IGroup(BaseEndpoint):
@@ -33,18 +33,225 @@ class IGroup(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}', domainUid)
 
-    def setExtId(self, uid, arg1):
-        postUri = "/{uid}/_extId"
+    def add(self, uid, members):
+        postUri = "/{uid}/members"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.STRING.encode(arg1)
+        from netbluemind.group.api.Member import Member
+        from netbluemind.group.api.Member import __MemberSerDer__
+        __data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def allUids(self):
+        postUri = "/_alluids"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
+    def byEmail(self, email):
+        postUri = "/byEmail/{email}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{email}", email)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
+
+    def byName(self, name):
+        postUri = "/byName/{name}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{name}", name)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
+
+    def create(self, uid, group):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        __data__ = __GroupSerDer__().encode(group)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def createWithExtId(self, uid, extid, group):
+        postUri = "/{uid}/{extid}/createwithextid"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        postUri = postUri.replace("{extid}", extid)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        __data__ = __GroupSerDer__().encode(group)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def delete(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def get(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.STRING.encode(uid)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        return self.handleResult__(__GroupSerDer__(), response)
+
+    def getByExtId(self, extid):
+        postUri = "/_extid/{extid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{extid}", extid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}/complete"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
+
+    def getExpandedMembers(self, uid):
+        postUri = "/{uid}/expandedmembers"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Member import Member
+        from netbluemind.group.api.Member import __MemberSerDer__
+        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
+
+    def getExpandedUserMembers(self, uid):
+        postUri = "/{uid}/expandedusersmembers"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Member import Member
+        from netbluemind.group.api.Member import __MemberSerDer__
+        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
+
+    def getGroupsWithRoles(self, roles):
+        postUri = "/_rolegroups"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getMembers(self, uid):
+        postUri = "/{uid}/members"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Member import Member
+        from netbluemind.group.api.Member import __MemberSerDer__
+        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
+
+    def getParents(self, uid):
+        postUri = "/{uid}/parents"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
+
+    def getRoles(self, uid):
+        postUri = "/{uid}/roles"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
 
     def memberOf(self, uid):
         postUri = "/{uid}/groups"
@@ -72,72 +279,6 @@ class IGroup(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
-    def getExpandedUserMembers(self, uid):
-        postUri = "/{uid}/expandedusersmembers"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Member import Member
-        from netbluemind.group.api.Member import __MemberSerDer__
-        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
-
-    def allUids(self):
-        postUri = "/_alluids"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
-    def update(self, uid, group):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        __data__ = __GroupSerDer__().encode(group)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def byName(self, name):
-        postUri = "/byName/{name}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{name}", name)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-
-    def delete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-
     def remove(self, uid, members):
         postUri = "/{uid}/members"
         __data__ = None
@@ -153,21 +294,6 @@ class IGroup(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getParents(self, uid):
-        postUri = "/{uid}/parents"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
-
     def search(self, query):
         postUri = "/_search"
         __data__ = None
@@ -186,47 +312,17 @@ class IGroup(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
 
-    def getExpandedMembers(self, uid):
-        postUri = "/{uid}/expandedmembers"
+    def setExtId(self, uid, arg1):
+        postUri = "/{uid}/_extId"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Member import Member
-        from netbluemind.group.api.Member import __MemberSerDer__
-        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
-
-    def byEmail(self, email):
-        postUri = "/byEmail/{email}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{email}", email)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-
-    def create(self, uid, group):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        __data__ = __GroupSerDer__().encode(group)
+        __data__ = serder.STRING.encode(arg1)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
     def setRoles(self, uid, roles):
@@ -242,110 +338,28 @@ class IGroup(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getRoles(self, uid):
-        postUri = "/{uid}/roles"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def add(self, uid, members):
-        postUri = "/{uid}/members"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.group.api.Member import Member
-        from netbluemind.group.api.Member import __MemberSerDer__
-        __data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getByExtId(self, extid):
-        postUri = "/_extid/{extid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{extid}", extid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-
-    def touch(self, uid):
+    def touch(self, uid, update_vcards):
         postUri = "/{uid}/_touch"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
+        queryParams = {'update_vcards': update_vcards}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getComplete(self, uid):
-        postUri = "/{uid}/complete"
+    def update(self, uid, group):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-
-    def getGroupsWithRoles(self, roles):
-        postUri = "/_rolegroups"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def createWithExtId(self, uid, extid, group):
-        postUri = "/{uid}/{extid}/createwithextid"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        postUri = postUri.replace("{extid}", extid)
         from netbluemind.group.api.Group import Group
         from netbluemind.group.api.Group import __GroupSerDer__
         __data__ = __GroupSerDer__().encode(group)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
-
-    def getMembers(self, uid):
-        postUri = "/{uid}/members"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IGroup_VERSION}, data=__encoded__)
-        from netbluemind.group.api.Member import Member
-        from netbluemind.group.api.Member import __MemberSerDer__
-        return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
