@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxMgmt_VERSION = "4.1.65172"
+IMailboxMgmt_VERSION = "5.0.7187"
 
 
 class IMailboxMgmt(BaseEndpoint):
@@ -33,6 +33,57 @@ class IMailboxMgmt(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}', domainUid)
 
+    def addIndexToRing(self, numericIndex):
+        postUri = "/{numericIndex}/_add_index"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{numericIndex}", numericIndex)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def consolidateDomain(self):
+        postUri = "/_consolidate"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def consolidateMailbox(self, mailboxUid):
+        postUri = "/{mailboxUid}/_consolidate"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{mailboxUid}", mailboxUid)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def deleteIndexFromRing(self, numericIndex):
+        postUri = "/{numericIndex}/_remove_index"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{numericIndex}", numericIndex)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+
     def getLiteStats(self):
         postUri = "/liteStats"
         __data__ = None
@@ -57,31 +108,6 @@ class IMailboxMgmt(BaseEndpoint):
         from netbluemind.mailbox.api.ShardStats import __ShardStatsSerDer__
         return self.handleResult__(serder.ListSerDer(__ShardStatsSerDer__()), response)
 
-    def consolidateMailbox(self, mailboxUid):
-        postUri = "/{mailboxUid}/_consolidate"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{mailboxUid}", mailboxUid)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-
-    def consolidateDomain(self):
-        postUri = "/_consolidate"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-
     def moveIndex(self, mailboxUid, index, deleteSource):
         postUri = "/{mailboxUid}/_move_index"
         __data__ = None
@@ -107,3 +133,16 @@ class IMailboxMgmt(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
+
+    def respawnMailbox(self, mailboxUid):
+        postUri = "/{mailboxUid}/_respawn"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{mailboxUid}", mailboxUid)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
