@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-INote_VERSION = "4.1.65172"
+INote_VERSION = "5.0.7187"
 
 
 class INote(BaseEndpoint):
@@ -33,48 +33,42 @@ class INote(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}', containerUid)
 
-    def getVersion(self):
-        postUri = "/_version"
+    def all(self):
+        postUri = ""
         __data__ = None
         __encoded__ = None
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.LONG, response)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
 
-    def filteredChangesetById(self, since, arg1):
-        postUri = "/_filteredChangesetById"
+    def allIds(self, filter, knownContainerVersion, limit, offset):
+        postUri = "/_itemIds"
         __data__ = None
         __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'since': since}
+        queryParams = {'filter': filter, 'knownContainerVersion':
+                       knownContainerVersion, 'limit': limit, 'offset': offset}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemVersion import ItemVersion
-        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
 
-    def itemChangelog(self, uid, arg1):
-        postUri = "/{uid}/_itemchangelog"
+    def allUids(self):
+        postUri = "/_all"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
     def changeset(self, since):
         postUri = "/_changeset"
@@ -100,33 +94,6 @@ class INote(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
 
-    def containerChangelog(self, arg0):
-        postUri = "/_changelog"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
-    def allIds(self, filter, knownContainerVersion, limit, offset):
-        postUri = "/_itemIds"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'filter': filter, 'knownContainerVersion':
-                       knownContainerVersion, 'limit': limit, 'offset': offset}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
-
     def count(self, arg0):
         postUri = "/_count"
         __data__ = None
@@ -143,75 +110,19 @@ class INote(BaseEndpoint):
         from netbluemind.core.container.api.Count import __CountSerDer__
         return self.handleResult__(__CountSerDer__(), response)
 
-    def multipleGetById(self, arg0):
-        postUri = "/_mgetById"
+    def create(self, uid, note):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        __data__ = __VNoteSerDer__().encode(note)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
-
-    def getCompleteById(self, id):
-        postUri = "/{id}/completeById"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VNoteSerDer__()), response)
-
-    def multipleDeleteById(self, arg0):
-        postUri = "/_multipleDelete"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def updateById(self, id, arg1):
-        postUri = "/id/{id}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        __data__ = __VNoteSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
-
-    def deleteById(self, id):
-        postUri = "/id/{id}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
     def createById(self, id, arg1):
@@ -231,61 +142,6 @@ class INote(BaseEndpoint):
         from netbluemind.core.container.api.Ack import __AckSerDer__
         return self.handleResult__(__AckSerDer__(), response)
 
-    def sortedIds(self, arg0):
-        postUri = "/_sorted"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
-        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
-        __data__ = __SortDescriptorSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
-
-    def allUids(self):
-        postUri = "/_all"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
-    def update(self, uid, note):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        __data__ = __VNoteSerDer__().encode(note)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def updates(self, changes):
-        postUri = "/_mupdates"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.notes.api.VNoteChanges import VNoteChanges
-        from netbluemind.notes.api.VNoteChanges import __VNoteChangesSerDer__
-        __data__ = __VNoteChangesSerDer__().encode(changes)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
-        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
-        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
-
     def delete(self, uid):
         postUri = "/{uid}"
         __data__ = None
@@ -297,6 +153,154 @@ class INote(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def deleteById(self, id):
+        postUri = "/id/{id}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def exportAll(self):
+        postUri = "/_exportall"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return response.content
+
+    def filteredChangesetById(self, since, arg1):
+        postUri = "/_filteredChangesetById"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {'since': since}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemVersion import ItemVersion
+        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}/complete"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VNoteSerDer__()), response)
+
+    def getCompleteById(self, id):
+        postUri = "/{id}/completeById"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VNoteSerDer__()), response)
+
+    def getVersion(self):
+        postUri = "/_version"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.LONG, response)
+
+    def itemChangelog(self, uid, arg1):
+        postUri = "/{uid}/_itemchangelog"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+
+    def multipleDeleteById(self, arg0):
+        postUri = "/_multipleDelete"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def multipleGet(self, uids):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
+
+    def multipleGetById(self, arg0):
+        postUri = "/_mgetById"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        from netbluemind.notes.api.VNote import VNote
+        from netbluemind.notes.api.VNote import __VNoteSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
+
+    def reset(self):
+        postUri = "/_reset"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
     def search(self, query):
         postUri = "/_search"
         __data__ = None
@@ -317,7 +321,21 @@ class INote(BaseEndpoint):
         from netbluemind.core.api.ListResult import __ListResultSerDer__
         return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VNoteSerDer__())), response)
 
-    def create(self, uid, note):
+    def sortedIds(self, arg0):
+        postUri = "/_sorted"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
+
+    def update(self, uid, note):
         postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
@@ -328,61 +346,39 @@ class INote(BaseEndpoint):
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def all(self):
-        postUri = ""
+    def updateById(self, id, arg1):
+        postUri = "/id/{id}"
         __data__ = None
         __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
+        postUri = postUri.replace("{id}", id)
         from netbluemind.notes.api.VNote import VNote
         from netbluemind.notes.api.VNote import __VNoteSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
-
-    def multipleGet(self, uids):
-        postUri = "/_mget"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __data__ = __VNoteSerDer__().encode(arg1)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VNoteSerDer__())), response)
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
 
-    def getComplete(self, uid):
-        postUri = "/{uid}/complete"
+    def updates(self, changes):
+        postUri = "/_mupdates"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.notes.api.VNoteChanges import VNoteChanges
+        from netbluemind.notes.api.VNoteChanges import __VNoteChangesSerDer__
+        __data__ = __VNoteChangesSerDer__().encode(changes)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        from netbluemind.notes.api.VNote import VNote
-        from netbluemind.notes.api.VNote import __VNoteSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VNoteSerDer__()), response)
-
-    def reset(self):
-        postUri = "/_reset"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': INote_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
+        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
+        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
