@@ -1,27 +1,28 @@
 #
 #  BEGIN LICENSE
 #  Copyright (c) Blue Mind SAS, 2012-2016
-# 
+#
 #  This file is part of BlueMind. BlueMind is a messaging and collaborative
 #  solution.
-# 
+#
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of either the GNU Affero General Public License as
 #  published by the Free Software Foundation (version 3 of the License).
-# 
-# 
+#
+#
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-# 
+#
 #  See LICENSE.txt
 #  END LICENSE
 #
 import requests
 from netbluemind.python import serder
 
-class CloneConfiguration :
-    def __init__( self):
+
+class CloneConfiguration:
+    def __init__(self):
         self.sourceInstallationId = None
         self.targetInstallationId = None
         self.uidToIpMapping = None
@@ -31,12 +32,13 @@ class CloneConfiguration :
         self.skippedContainerTypes = None
         pass
 
+
 class __CloneConfigurationSerDer__:
-    def __init__( self ):
+    def __init__(self):
         pass
 
     def parse(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = CloneConfiguration()
 
@@ -45,13 +47,17 @@ class __CloneConfigurationSerDer__:
 
     def parseInternal(self, value, instance):
         sourceInstallationIdValue = value['sourceInstallationId']
-        instance.sourceInstallationId = serder.STRING.parse(sourceInstallationIdValue)
+        instance.sourceInstallationId = serder.STRING.parse(
+            sourceInstallationIdValue)
         targetInstallationIdValue = value['targetInstallationId']
-        instance.targetInstallationId = serder.STRING.parse(targetInstallationIdValue)
+        instance.targetInstallationId = serder.STRING.parse(
+            targetInstallationIdValue)
         uidToIpMappingValue = value['uidToIpMapping']
-        instance.uidToIpMapping = serder.MapSerDer(serder.STRING).parse(uidToIpMappingValue)
+        instance.uidToIpMapping = serder.MapSerDer(
+            serder.STRING).parse(uidToIpMappingValue)
         sysconfOverrideValue = value['sysconfOverride']
-        instance.sysconfOverride = serder.MapSerDer(serder.STRING).parse(sysconfOverrideValue)
+        instance.sysconfOverride = serder.MapSerDer(
+            serder.STRING).parse(sysconfOverrideValue)
         from netbluemind.system.api.CloneConfigurationMode import CloneConfigurationMode
         from netbluemind.system.api.CloneConfigurationMode import __CloneConfigurationModeSerDer__
         modeValue = value['mode']
@@ -59,26 +65,31 @@ class __CloneConfigurationSerDer__:
         cloneWorkersValue = value['cloneWorkers']
         instance.cloneWorkers = serder.INT.parse(cloneWorkersValue)
         skippedContainerTypesValue = value['skippedContainerTypes']
-        instance.skippedContainerTypes = serder.SetSerDer(serder.STRING).parse(skippedContainerTypesValue)
+        instance.skippedContainerTypes = serder.SetSerDer(
+            serder.STRING).parse(skippedContainerTypesValue)
         return instance
 
     def encode(self, value):
-        if(value == None):
+        if (value == None):
             return None
         instance = dict()
-        self.encodeInternal(value,instance)
+        self.encodeInternal(value, instance)
         return instance
 
     def encodeInternal(self, value, instance):
 
         sourceInstallationIdValue = value.sourceInstallationId
-        instance["sourceInstallationId"] = serder.STRING.encode(sourceInstallationIdValue)
+        instance["sourceInstallationId"] = serder.STRING.encode(
+            sourceInstallationIdValue)
         targetInstallationIdValue = value.targetInstallationId
-        instance["targetInstallationId"] = serder.STRING.encode(targetInstallationIdValue)
+        instance["targetInstallationId"] = serder.STRING.encode(
+            targetInstallationIdValue)
         uidToIpMappingValue = value.uidToIpMapping
-        instance["uidToIpMapping"] = serder.MapSerDer(serder.STRING).encode(uidToIpMappingValue)
+        instance["uidToIpMapping"] = serder.MapSerDer(
+            serder.STRING).encode(uidToIpMappingValue)
         sysconfOverrideValue = value.sysconfOverride
-        instance["sysconfOverride"] = serder.MapSerDer(serder.STRING).encode(sysconfOverrideValue)
+        instance["sysconfOverride"] = serder.MapSerDer(
+            serder.STRING).encode(sysconfOverrideValue)
         from netbluemind.system.api.CloneConfigurationMode import CloneConfigurationMode
         from netbluemind.system.api.CloneConfigurationMode import __CloneConfigurationModeSerDer__
         modeValue = value.mode
@@ -86,6 +97,6 @@ class __CloneConfigurationSerDer__:
         cloneWorkersValue = value.cloneWorkers
         instance["cloneWorkers"] = serder.INT.encode(cloneWorkersValue)
         skippedContainerTypesValue = value.skippedContainerTypes
-        instance["skippedContainerTypes"] = serder.SetSerDer(serder.STRING).encode(skippedContainerTypesValue)
+        instance["skippedContainerTypes"] = serder.SetSerDer(
+            serder.STRING).encode(skippedContainerTypesValue)
         return instance
-
