@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ISecurityMgmt_VERSION = "4.1.65172"
+ISecurityMgmt_VERSION = "5.0.7187"
 
 
 class ISecurityMgmt(BaseEndpoint):
@@ -31,17 +31,16 @@ class ISecurityMgmt(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url + '/system/security'
 
-    def updateFirewallRules(self):
-        postUri = "/_updatefirewallrules"
+    def approveLetsEncryptTos(self, uid):
+        postUri = "/lets_encrypt_tos/{uid}"
         __data__ = None
         __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISecurityMgmt_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISecurityMgmt_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
 
     def generateLetsEncrypt(self, certData):
         postUri = "/lets_encrypt"
@@ -59,16 +58,15 @@ class ISecurityMgmt(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
 
-    def approveLetsEncryptTos(self, uid):
-        postUri = "/lets_encrypt_tos/{uid}"
+    def getLetsEncryptTos(self):
+        postUri = "/lets_encrypt_tos"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
         queryParams = {}
 
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISecurityMgmt_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        return self.handleResult__(serder.STRING, response)
 
     def updateCertificate(self, certData):
         postUri = ""
@@ -83,13 +81,3 @@ class ISecurityMgmt(BaseEndpoint):
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISecurityMgmt_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
-
-    def getLetsEncryptTos(self):
-        postUri = "/lets_encrypt_tos"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ISecurityMgmt_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.STRING, response)
