@@ -34,6 +34,8 @@ class HotUpgradeTask:
         self.retryCount = None
         self.retryDelaySeconds = None
         self.reportFailure = None
+        self.mandatory = None
+        self.events = None
         pass
 
 
@@ -76,6 +78,13 @@ class __HotUpgradeTaskSerDer__:
         instance.retryDelaySeconds = serder.INT.parse(retryDelaySecondsValue)
         reportFailureValue = value['reportFailure']
         instance.reportFailure = serder.BOOLEAN.parse(reportFailureValue)
+        mandatoryValue = value['mandatory']
+        instance.mandatory = serder.BOOLEAN.parse(mandatoryValue)
+        from netbluemind.system.api.hot.upgrade.HotUpgradeStepEvent import HotUpgradeStepEvent
+        from netbluemind.system.api.hot.upgrade.HotUpgradeStepEvent import __HotUpgradeStepEventSerDer__
+        eventsValue = value['events']
+        instance.events = serder.ListSerDer(
+            __HotUpgradeStepEventSerDer__()).parse(eventsValue)
         return instance
 
     def encode(self, value):
@@ -115,4 +124,11 @@ class __HotUpgradeTaskSerDer__:
             retryDelaySecondsValue)
         reportFailureValue = value.reportFailure
         instance["reportFailure"] = serder.BOOLEAN.encode(reportFailureValue)
+        mandatoryValue = value.mandatory
+        instance["mandatory"] = serder.BOOLEAN.encode(mandatoryValue)
+        from netbluemind.system.api.hot.upgrade.HotUpgradeStepEvent import HotUpgradeStepEvent
+        from netbluemind.system.api.hot.upgrade.HotUpgradeStepEvent import __HotUpgradeStepEventSerDer__
+        eventsValue = value.events
+        instance["events"] = serder.ListSerDer(
+            __HotUpgradeStepEventSerDer__()).encode(eventsValue)
         return instance
