@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ITags_VERSION = "4.1.65172"
+ITags_VERSION = "5.0.7187"
 
 
 class ITags(BaseEndpoint):
@@ -47,6 +47,69 @@ class ITags(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)
 
+    def allUids(self):
+        postUri = "/_alluids"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
+    def changeset(self, since):
+        postUri = "/_changeset"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {'since': since}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+
+    def create(self, uid, tag):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.tag.api.Tag import Tag
+        from netbluemind.tag.api.Tag import __TagSerDer__
+        __data__ = __TagSerDer__().encode(tag)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def delete(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
+        from netbluemind.tag.api.Tag import Tag
+        from netbluemind.tag.api.Tag import __TagSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__TagSerDer__()), response)
+
     def multipleGet(self, uids):
         postUri = "/_mget"
         __data__ = None
@@ -63,28 +126,6 @@ class ITags(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)
 
-    def allUids(self):
-        postUri = "/_alluids"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
-    def changelog(self, since):
-        postUri = "/_changelog"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'since': since}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
     def update(self, uid, tag):
         postUri = "/{uid}"
         __data__ = None
@@ -115,56 +156,3 @@ class ITags(BaseEndpoint):
         from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
         from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
         return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
-
-    def delete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def changeset(self, since):
-        postUri = "/_changeset"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'since': since}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-
-    def getComplete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        from netbluemind.tag.api.Tag import Tag
-        from netbluemind.tag.api.Tag import __TagSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__TagSerDer__()), response)
-
-    def create(self, uid, tag):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.tag.api.Tag import Tag
-        from netbluemind.tag.api.Tag import __TagSerDer__
-        __data__ = __TagSerDer__().encode(tag)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
