@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ITodoList_VERSION = "4.1.65172"
+ITodoList_VERSION = "5.0.7187"
 
 
 class ITodoList(BaseEndpoint):
@@ -33,48 +33,42 @@ class ITodoList(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}', containerUid)
 
-    def getVersion(self):
-        postUri = "/_version"
+    def all(self):
+        postUri = ""
         __data__ = None
         __encoded__ = None
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.LONG, response)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
 
-    def filteredChangesetById(self, since, arg1):
-        postUri = "/_filteredChangesetById"
+    def allIds(self, filter, knownContainerVersion, limit, offset):
+        postUri = "/_itemIds"
         __data__ = None
         __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {'since': since}
+        queryParams = {'filter': filter, 'knownContainerVersion':
+                       knownContainerVersion, 'limit': limit, 'offset': offset}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemVersion import ItemVersion
-        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
 
-    def itemChangelog(self, uid, arg1):
-        postUri = "/{uid}/_itemchangelog"
+    def allUids(self):
+        postUri = "/_all"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
     def changeset(self, since):
         postUri = "/_changeset"
@@ -100,32 +94,18 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
 
-    def containerChangelog(self, arg0):
-        postUri = "/_changelog"
+    def copy(self, uids, destContainerUid):
+        postUri = "/_copy/{destContainerUid}"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
         __encoded__ = json.dumps(__data__)
+        postUri = postUri.replace("{destContainerUid}", destContainerUid)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
-
-    def allIds(self, filter, knownContainerVersion, limit, offset):
-        postUri = "/_itemIds"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {'filter': filter, 'knownContainerVersion':
-                       knownContainerVersion, 'limit': limit, 'offset': offset}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
 
     def count(self, arg0):
         postUri = "/_count"
@@ -143,75 +123,19 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.api.Count import __CountSerDer__
         return self.handleResult__(__CountSerDer__(), response)
 
-    def multipleGetById(self, arg0):
-        postUri = "/_mgetById"
+    def create(self, uid, todo):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        __data__ = __VTodoSerDer__().encode(todo)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
-
-    def getCompleteById(self, id):
-        postUri = "/{id}/completeById"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
-
-    def multipleDeleteById(self, arg0):
-        postUri = "/_multipleDelete"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def updateById(self, id, arg1):
-        postUri = "/id/{id}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        __data__ = __VTodoSerDer__().encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
-
-    def deleteById(self, id):
-        postUri = "/id/{id}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}", id)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
     def createById(self, id, arg1):
@@ -231,61 +155,6 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.api.Ack import __AckSerDer__
         return self.handleResult__(__AckSerDer__(), response)
 
-    def sortedIds(self, arg0):
-        postUri = "/_sorted"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
-        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
-        __data__ = __SortDescriptorSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
-
-    def allUids(self):
-        postUri = "/_all"
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-
-    def update(self, uid, todo):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        __data__ = __VTodoSerDer__().encode(todo)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def updates(self, changes):
-        postUri = "/_mupdates"
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.todolist.api.VTodoChanges import VTodoChanges
-        from netbluemind.todolist.api.VTodoChanges import __VTodoChangesSerDer__
-        __data__ = __VTodoChangesSerDer__().encode(changes)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
-        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
-        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
-
     def delete(self, uid):
         postUri = "/{uid}"
         __data__ = None
@@ -297,6 +166,172 @@ class ITodoList(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def deleteById(self, id):
+        postUri = "/id/{id}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def filteredChangesetById(self, since, arg1):
+        postUri = "/_filteredChangesetById"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {'since': since}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemVersion import ItemVersion
+        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+
+    def getByIcsUid(self, uid):
+        postUri = "/_icsuid/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}/complete"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
+
+    def getCompleteById(self, id):
+        postUri = "/{id}/completeById"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
+
+    def getVersion(self):
+        postUri = "/_version"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.LONG, response)
+
+    def itemChangelog(self, uid, arg1):
+        postUri = "/{uid}/_itemchangelog"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+
+    def move(self, uids, destContainerUid):
+        postUri = "/_move/{destContainerUid}"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        postUri = postUri.replace("{destContainerUid}", destContainerUid)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def multipleDeleteById(self, arg0):
+        postUri = "/_multipleDelete"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def multipleGet(self, uids):
+        postUri = "/_mget"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+
+    def multipleGetById(self, arg0):
+        postUri = "/_mgetById"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+
+    def reset(self):
+        postUri = "/_reset"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
     def search(self, query):
         postUri = "/_search"
         __data__ = None
@@ -317,76 +352,19 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.api.ListResult import __ListResultSerDer__
         return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VTodoSerDer__())), response)
 
-    def create(self, uid, todo):
-        postUri = "/{uid}"
+    def sortedIds(self, arg0):
+        postUri = "/_sorted"
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        __data__ = __VTodoSerDer__().encode(todo)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def copy(self, uids, destContainerUid):
-        postUri = "/_copy/{destContainerUid}"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        postUri = postUri.replace("{destContainerUid}", destContainerUid)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def all(self):
-        postUri = ""
-        __data__ = None
-        __encoded__ = None
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
-
-    def move(self, uids, destContainerUid):
-        postUri = "/_move/{destContainerUid}"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
-        __encoded__ = json.dumps(__data__)
-        postUri = postUri.replace("{destContainerUid}", destContainerUid)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def multipleGet(self, uids):
-        postUri = "/_mget"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
-        from netbluemind.todolist.api.VTodo import VTodo
-        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
+        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
 
     def sync(self, since, changes):
         postUri = "/_sync"
@@ -404,27 +382,50 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
 
-    def getComplete(self, uid):
-        postUri = "/{uid}/complete"
+    def update(self, uid, todo):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
         from netbluemind.todolist.api.VTodo import VTodo
         from netbluemind.todolist.api.VTodo import __VTodoSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
-
-    def reset(self):
-        postUri = "/_reset"
-        __data__ = None
-        __encoded__ = None
+        __data__ = __VTodoSerDer__().encode(todo)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
+
+    def updateById(self, id, arg1):
+        postUri = "/id/{id}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}", id)
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        __data__ = __VTodoSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+
+    def updates(self, changes):
+        postUri = "/_mupdates"
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.todolist.api.VTodoChanges import VTodoChanges
+        from netbluemind.todolist.api.VTodoChanges import __VTodoChangesSerDer__
+        __data__ = __VTodoChangesSerDer__().encode(changes)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITodoList_VERSION}, data=__encoded__)
+        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
+        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
+        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
