@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IUser_VERSION = "4.1.65172"
+IUser_VERSION = "5.0.7187"
 
 
 class IUser(BaseEndpoint):
@@ -33,16 +33,104 @@ class IUser(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}', domainUid)
 
-    def getPhoto(self, uid):
-        postUri = "/{uid}/photo"
+    def allUids(self):
+        postUri = "/_alluids"
+        __data__ = None
+        __encoded__ = None
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+
+    def byEmail(self, email):
+        postUri = "/byEmail/{email}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{email}", email)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+
+    def byExtId(self, extid):
+        postUri = "/byExtId/{extid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{extid}", extid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+
+    def byLogin(self, login):
+        postUri = "/byLogin/{login}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{login}", login)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+
+    def create(self, uid, user):
+        postUri = "/{uid}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        __data__ = __UserSerDer__().encode(user)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def createWithExtId(self, uid, extid, user):
+        postUri = "/{uid}/{extid}/createwithextid"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        postUri = postUri.replace("{extid}", extid)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        __data__ = __UserSerDer__().encode(user)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def delete(self, uid):
+        postUri = "/{uid}"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ByteArraySerDer, response)
+        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
+                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
 
     def deletePhoto(self, uid):
         postUri = "/{uid}/photo"
@@ -55,6 +143,35 @@ class IUser(BaseEndpoint):
                                    'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
+    def enablePerUserLog(self, userUid, endpoint, enable):
+        postUri = "/{userUid}/_logging/{endpoint}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{userUid}", userUid)
+        postUri = postUri.replace("{endpoint}", endpoint)
+        __data__ = serder.BOOLEAN.encode(enable)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def getComplete(self, uid):
+        postUri = "/{uid}/complete"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.user.api.User import User
+        from netbluemind.user.api.User import __UserSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
+
     def getIcon(self, uid):
         postUri = "/{uid}/icon"
         __data__ = None
@@ -66,31 +183,63 @@ class IUser(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ByteArraySerDer, response)
 
-    def setPhoto(self, uid, arg1):
+    def getPhoto(self, uid):
         postUri = "/{uid}/photo"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.ByteArraySerDer.encode(arg1)
-        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.ByteArraySerDer, response)
 
-    def setExtId(self, uid, arg1):
-        postUri = "/{uid}/_extId"
+    def getResolvedRoles(self, uid):
+        postUri = "/{uid}/roles_resolved"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.STRING.encode(arg1)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getRoles(self, uid):
+        postUri = "/{uid}/roles"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getUsersWithRoles(self, roles):
+        postUri = "/_roleusers"
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
         __encoded__ = json.dumps(__data__)
         queryParams = {}
 
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
+        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
+
+    def getVCard(self, uid):
+        postUri = "/{uid}/vcard"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        queryParams = {}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        return self.handleResult__(__VCardSerDer__(), response)
 
     def memberOf(self, uid):
         postUri = "/{uid}/groups"
@@ -118,6 +267,19 @@ class IUser(BaseEndpoint):
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
 
+    def setExtId(self, uid, arg1):
+        postUri = "/{uid}/_extId"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.STRING.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
     def setPassword(self, uid, password):
         postUri = "/{uid}/password_"
         __data__ = None
@@ -133,15 +295,31 @@ class IUser(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def allUids(self):
-        postUri = "/_alluids"
+    def setPhoto(self, uid, arg1):
+        postUri = "/{uid}/photo"
         __data__ = None
         __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.ByteArraySerDer.encode(arg1)
+        __encoded__ = json.dumps(__data__)
         queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
+
+    def setRoles(self, uid, roles):
+        postUri = "/{uid}/roles"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}", uid)
+        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
+
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
 
     def update(self, uid, user):
         postUri = "/{uid}"
@@ -158,32 +336,6 @@ class IUser(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getVCard(self, uid):
-        postUri = "/{uid}/vcard"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        return self.handleResult__(__VCardSerDer__(), response)
-
-    def delete(self, uid):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
-                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-
     def updateAccountType(self, uid, accountType):
         postUri = "/_updateAccountType/{uid}"
         __data__ = None
@@ -199,86 +351,6 @@ class IUser(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def getResolvedRoles(self, uid):
-        postUri = "/{uid}/roles_resolved"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def byLogin(self, login):
-        postUri = "/byLogin/{login}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{login}", login)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-
-    def byEmail(self, email):
-        postUri = "/byEmail/{email}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{email}", email)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-
-    def create(self, uid, user):
-        postUri = "/{uid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        __data__ = __UserSerDer__().encode(user)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def setRoles(self, uid, roles):
-        postUri = "/{uid}/roles"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
-
-    def getRoles(self, uid):
-        postUri = "/{uid}/roles"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
     def updateVCard(self, uid, userVCard):
         postUri = "/{uid}/vcard"
         __data__ = None
@@ -293,61 +365,3 @@ class IUser(BaseEndpoint):
         response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
-
-    def byExtId(self, extid):
-        postUri = "/byExtId/{extid}"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{extid}", extid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-
-    def getComplete(self, uid):
-        postUri = "/{uid}/complete"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        queryParams = {}
-
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-
-    def getUsersWithRoles(self, roles):
-        postUri = "/_roleusers"
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
-                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
-
-    def createWithExtId(self, uid, extid, user):
-        postUri = "/{uid}/{extid}/createwithextid"
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}", uid)
-        postUri = postUri.replace("{extid}", extid)
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        __data__ = __UserSerDer__().encode(user)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {}
-
-        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
-        return self.handleResult__(None, response)
