@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IUserSubscription_VERSION = "4.1.65172"
+IUserSubscription_VERSION = "5.0.7187"
 
 
 class IUserSubscription(BaseEndpoint):
@@ -33,6 +33,19 @@ class IUserSubscription(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}', domainUid)
 
+    def listSubscriptions(self, subject, type):
+        postUri = "/{subject}"
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{subject}", subject)
+        queryParams = {'type': type}
+
+        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
+                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
+        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import ContainerSubscriptionDescriptor
+        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import __ContainerSubscriptionDescriptorSerDer__
+        return self.handleResult__(serder.ListSerDer(__ContainerSubscriptionDescriptorSerDer__()), response)
+
     def subscribe(self, subject, subscriptions):
         postUri = "/{subject}/_subscribe"
         __data__ = None
@@ -73,15 +86,18 @@ class IUserSubscription(BaseEndpoint):
                                  'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
         return self.handleResult__(None, response)
 
-    def listSubscriptions(self, subject, type):
-        postUri = "/{subject}"
+    def updateAutomount(self, subject, subscriptions):
+        postUri = "/{subject}/_automount"
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{subject}", subject)
-        queryParams = {'type': type}
+        from netbluemind.core.container.api.ContainerSubscription import ContainerSubscription
+        from netbluemind.core.container.api.ContainerSubscription import __ContainerSubscriptionSerDer__
+        __data__ = serder.ListSerDer(
+            __ContainerSubscriptionSerDer__()).encode(subscriptions)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {}
 
-        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
-                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
-        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import ContainerSubscriptionDescriptor
-        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import __ContainerSubscriptionDescriptorSerDer__
-        return self.handleResult__(serder.ListSerDer(__ContainerSubscriptionDescriptorSerDer__()), response)
+        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
+                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
+        return self.handleResult__(None, response)
